DROP TABLE IF EXISTS "array" CASCADE ;
CREATE TABLE "array" (
  "array_id" INTEGER  NOT NULL,
  "array_name" VARCHAR(50) NOT NULL,
  "description" TEXT,
  PRIMARY KEY ( "array_id" ),
  UNIQUE ( "array_name" )
) ;

DROP TABLE IF EXISTS "probe" CASCADE ;
CREATE TABLE "probe" (
  "probe_id" INTEGER  NOT NULL,
  "sequence" VARCHAR(40) NOT NULL,
  "probe_hit_count" INTEGER  NOT NULL,
  PRIMARY KEY ( "probe_id" )
) ;
CREATE INDEX ON "probe" ( "probe_hit_count" ) ;
CREATE INDEX ON "probe" ( "sequence" ) ;

DROP TABLE IF EXISTS "chromosome" CASCADE ;
CREATE TABLE "chromosome" (
  "chromosome_id" INTEGER  NOT NULL,
  "name" VARCHAR(40) NOT NULL,
  "length" INTEGER  NOT NULL,
  PRIMARY KEY ( "chromosome_id" ),
  UNIQUE ( "name" )
) ;

DROP TABLE IF EXISTS "synonym" CASCADE ;
CREATE TABLE "synonym" (
  "synonym_id" INTEGER  NOT NULL,
  "synonym" VARCHAR(40) NOT NULL
) ;
CREATE INDEX ON "synonym" ( "synonym_id" ) ;
CREATE INDEX ON "synonym" ( "synonym" ) ;

DROP TABLE IF EXISTS "probeset" CASCADE ;
CREATE TABLE "probeset" (
  "probeset_id" INTEGER  NOT NULL,
  "stable_id" VARCHAR(40) NOT NULL,
  "array_id" INTEGER  NOT NULL,
  "array_name" VARCHAR(50) NOT NULL,
  "probe_count" INTEGER  NOT NULL,
  "hit_score" SMALLINT  NOT NULL DEFAULT 0,
  "gene_score" SMALLINT  NOT NULL DEFAULT 0,
  "transcript_score" SMALLINT  NOT NULL DEFAULT 0,
  "exon_score" SMALLINT  NOT NULL DEFAULT 0,
  "est_gene_score" SMALLINT  NOT NULL DEFAULT 0,
  "est_transcript_score" SMALLINT  NOT NULL DEFAULT 0,
  "est_exon_score" SMALLINT  NOT NULL DEFAULT 0,
  "prediction_transcript_score" SMALLINT  NOT NULL DEFAULT 0,
  "prediction_exon_score" SMALLINT  NOT NULL DEFAULT 0,
  "protein_score" SMALLINT  NOT NULL DEFAULT 0,
  "domain_score" SMALLINT  NOT NULL DEFAULT 0,
  PRIMARY KEY ( "probeset_id" ),
  FOREIGN KEY ( "array_id" ) REFERENCES "array"( "array_id" )
) ;
CREATE INDEX ON "probeset" ( "stable_id", "array_id" ) ;
CREATE INDEX ON "probeset" ( "array_name" ) ;

DROP TABLE IF EXISTS "probemap" CASCADE ;
CREATE TABLE "probemap" (
  "probeset_id" INTEGER  NOT NULL,
  "probe_index" INTEGER  NOT NULL,
  "probe_id" INTEGER  NOT NULL,
  PRIMARY KEY ( "probeset_id", "probe_index", "probe_id" ),
  FOREIGN KEY ( "probeset_id" ) REFERENCES "probeset"( "probeset_id" ),
  FOREIGN KEY ( "probe_id" ) REFERENCES "probe"( "probe_id" )
) ;
CREATE INDEX ON "probemap" ( "probeset_id" ) ;
CREATE INDEX ON "probemap" ( "probe_id" ) ;

DROP TABLE IF EXISTS "hit" CASCADE ;
CREATE TABLE "hit" (
  "hit_id" INTEGER  NOT NULL,
  "probe_id" INTEGER  NOT NULL,
  "chromosome_id" INTEGER  NOT NULL,
  "chromosome_name" VARCHAR(40) NOT NULL,
  "start" INTEGER  NOT NULL,
  "end" INTEGER  NOT NULL,
  "strand" SMALLINT NOT NULL,
  PRIMARY KEY ( "hit_id" ),
  FOREIGN KEY ( "probe_id" ) REFERENCES "probe"( "probe_id" ),
  FOREIGN KEY ( "chromosome_id" ) REFERENCES "chromosome"( "chromosome_id" )
) ;
CREATE INDEX ON "hit" ( "probe_id" ) ;
CREATE INDEX ON "hit" ( "chromosome_name", "strand", "start" ) ;

DROP TABLE IF EXISTS "gene" CASCADE ;
CREATE TABLE "gene" (
  "gene_id" INTEGER  NOT NULL,
  "stable_id" VARCHAR(128) NOT NULL,
  "chromosome_id" INTEGER  NOT NULL,
  "chromosome_name" VARCHAR(40) NOT NULL,
  "start" INTEGER  NOT NULL,
  "end" INTEGER  NOT NULL,
  "strand" SMALLINT,
  "biotype" VARCHAR(40),
  "status" VARCHAR(128),
  "description" TEXT,
  "synonym_id" INTEGER  DEFAULT NULL,
  "external_db_id" INTEGER  DEFAULT NULL,
  "db_display_name" VARCHAR(255) DEFAULT NULL,
  "symbol" VARCHAR(128) DEFAULT NULL,
  "symbol_description" TEXT DEFAULT NULL,
  "analysis_name" VARCHAR(128) DEFAULT NULL,
  PRIMARY KEY ( "gene_id" ),
  UNIQUE ( "stable_id" ),
  FOREIGN KEY ( "chromosome_id" ) REFERENCES "chromosome"( "chromosome_id" )
) ;
CREATE INDEX ON "gene" ( "chromosome_name" ) ;
CREATE INDEX ON "gene" ( "start" ) ;
CREATE INDEX ON "gene" ( "end" ) ;
CREATE INDEX ON "gene" ( "strand" ) ;
CREATE INDEX ON "gene" ( "synonym_id" ) ;
CREATE INDEX ON "gene" ( "symbol" ) ;

DROP TABLE IF EXISTS "hit_gene" CASCADE ;
CREATE TABLE "hit_gene" (
  "hit_id" INTEGER  NOT NULL,
  "gene_id" INTEGER  NOT NULL,
  PRIMARY KEY ( "hit_id", "gene_id" ),
  FOREIGN KEY ( "hit_id" ) REFERENCES "hit"( "hit_id" ),
  FOREIGN KEY ( "gene_id" ) REFERENCES "gene"( "gene_id" )
) ;
CREATE INDEX ON "hit_gene" ( "hit_id" ) ;
CREATE INDEX ON "hit_gene" ( "gene_id" ) ;

DROP TABLE IF EXISTS "exon" CASCADE ;
CREATE TABLE "exon" (
  "exon_id" INTEGER  NOT NULL,
  "stable_id" VARCHAR(128) NOT NULL,
  "chromosome_id" INTEGER  NOT NULL,
  "chromosome_name" VARCHAR(40) NOT NULL,
  "start" INTEGER  NOT NULL,
  "end" INTEGER  NOT NULL,
  "strand" SMALLINT NOT NULL,
  "phase" SMALLINT NOT NULL,
  "end_phase" SMALLINT NOT NULL,
  "sequence" TEXT,
  PRIMARY KEY ( "exon_id" ),
  UNIQUE ( "stable_id" ),
  FOREIGN KEY ( "chromosome_id" ) REFERENCES "chromosome"( "chromosome_id" )
) ;
CREATE INDEX ON "exon" ( "chromosome_name" ) ;
CREATE INDEX ON "exon" ( "start" ) ;
CREATE INDEX ON "exon" ( "end" ) ;
CREATE INDEX ON "exon" ( "strand" ) ;

DROP TABLE IF EXISTS "hit_exon" CASCADE ;
CREATE TABLE "hit_exon" (
  "hit_id" INTEGER  NOT NULL,
  "exon_id" INTEGER  NOT NULL,
  PRIMARY KEY ( "hit_id", "exon_id" ),
  FOREIGN KEY ( "hit_id" ) REFERENCES "hit"( "hit_id" ),
  FOREIGN KEY ( "exon_id" ) REFERENCES "exon"( "exon_id" )
) ;
CREATE INDEX ON "hit_exon" ( "hit_id" ) ;
CREATE INDEX ON "hit_exon" ( "exon_id" ) ;

DROP TABLE IF EXISTS "transcript" CASCADE ;
CREATE TABLE "transcript" (
  "transcript_id" INTEGER  NOT NULL,
  "stable_id" VARCHAR(128) NOT NULL,
  "gene_id" INTEGER  NOT NULL,
  "chromosome_id" INTEGER  NOT NULL,
  "chromosome_name" VARCHAR(40) NOT NULL,
  "start" INTEGER  NOT NULL,
  "end" INTEGER  NOT NULL,
  "strand" SMALLINT NOT NULL,
  "biotype" VARCHAR(40) NOT NULL,
  "status" VARCHAR(128),
  "description" TEXT,
  "synonym_id" INTEGER  DEFAULT NULL,
  "external_db_id" INTEGER  DEFAULT NULL,
  "db_display_name" VARCHAR(255) DEFAULT NULL,
  "symbol" VARCHAR(128) DEFAULT NULL,
  "symbol_description" TEXT DEFAULT NULL,
  "translation_start" INTEGER,
  "translation_start_exon" INTEGER,
  "translation_end" INTEGER,
  "translation_end_exon" INTEGER,
  "analysis_name" VARCHAR(128) DEFAULT NULL,
  PRIMARY KEY ( "transcript_id" ),
  UNIQUE ( "stable_id" ),
  FOREIGN KEY ( "chromosome_id" ) REFERENCES "chromosome"( "chromosome_id" ),
  FOREIGN KEY ( "gene_id" ) REFERENCES "gene"( "gene_id" ),
  FOREIGN KEY ( "translation_start_exon" ) REFERENCES "exon"( "exon_id" ),
  FOREIGN KEY ( "translation_end_exon" ) REFERENCES "exon"( "exon_id" )
) ;
CREATE INDEX ON "transcript" ( "gene_id" ) ;
CREATE INDEX ON "transcript" ( "chromosome_name" ) ;
CREATE INDEX ON "transcript" ( "translation_start_exon" ) ;
CREATE INDEX ON "transcript" ( "translation_end_exon" ) ;
CREATE INDEX ON "transcript" ( "strand" ) ;
CREATE INDEX ON "transcript" ( "synonym_id" ) ;

DROP TABLE IF EXISTS "protein" CASCADE ;
CREATE TABLE "protein" (
  "protein_id" INTEGER  NOT NULL,
  "stable_id" VARCHAR(40) NOT NULL,
  "gene_id" INTEGER  NOT NULL,
  "transcript_id" INTEGER  NOT NULL,
  "chromosome_id" INTEGER  NOT NULL,
  "chromosome_name" VARCHAR(40) NOT NULL,
  "start" INTEGER  NOT NULL,
  "end" INTEGER  NOT NULL,
  "strand" SMALLINT,
  PRIMARY KEY ( "protein_id" ),
  UNIQUE ( "stable_id" ),
  FOREIGN KEY ( "gene_id" ) REFERENCES "gene"( "gene_id" ),
  FOREIGN KEY ( "transcript_id" ) REFERENCES "transcript"( "transcript_id" ),
  FOREIGN KEY ( "chromosome_id" ) REFERENCES "chromosome"( "chromosome_id" )
) ;
CREATE INDEX ON "protein" ( "gene_id" ) ;
CREATE INDEX ON "protein" ( "transcript_id" ) ;
CREATE INDEX ON "protein" ( "chromosome_name", "strand", "start", "end" ) ;

DROP TABLE IF EXISTS "domain" CASCADE ;
CREATE TABLE "domain" (
  "hit_id" INTEGER  NOT NULL,
  "stable_id" VARCHAR(7) NOT NULL,
  "symbol" VARCHAR(40) NOT NULL,
  "description" VARCHAR(100) NOT NULL,
  "model_length" INTEGER ,
  "type" VARCHAR(255),
  "protein_id" INTEGER  NOT NULL,
  "seq_start" INTEGER  NOT NULL,
  "seq_end" INTEGER  NOT NULL,
  "hmm_start" INTEGER  NOT NULL,
  "hmm_end" INTEGER  NOT NULL,
  "bit_score" DOUBLE PRECISION,
  "evalue" DOUBLE PRECISION,
  "chromosome_id" INTEGER  NOT NULL,
  "chromosome_name" VARCHAR(40) NOT NULL,
  "start" INTEGER  NOT NULL,
  "end" INTEGER  NOT NULL,
  "strand" SMALLINT,
  PRIMARY KEY ( "hit_id" ),
  FOREIGN KEY ( "protein_id" ) REFERENCES "protein"( "protein_id" ),
  FOREIGN KEY ( "chromosome_id" ) REFERENCES "chromosome"( "chromosome_id" )
) ;
CREATE INDEX ON "domain" ( "protein_id" ) ;
CREATE INDEX ON "domain" ( "stable_id" ) ;
CREATE INDEX ON "domain" ( "chromosome_name", "strand", "start", "end" ) ;

DROP TABLE IF EXISTS "hit_transcript" CASCADE ;
CREATE TABLE "hit_transcript" (
  "hit_id" INTEGER  NOT NULL,
  "transcript_id" INTEGER  NOT NULL,
  PRIMARY KEY ( "hit_id", "transcript_id" ),
  FOREIGN KEY ( "hit_id" ) REFERENCES "hit"( "hit_id" ),
  FOREIGN KEY ( "transcript_id" ) REFERENCES "transcript"( "transcript_id" )
) ;
CREATE INDEX ON "hit_transcript" ( "hit_id" ) ;
CREATE INDEX ON "hit_transcript" ( "transcript_id" ) ;

DROP TABLE IF EXISTS "hit_protein" CASCADE ;
CREATE TABLE "hit_protein" (
  "hit_id" INTEGER  NOT NULL,
  "protein_id" INTEGER  NOT NULL,
  PRIMARY KEY ( "hit_id", "protein_id" ),
  FOREIGN KEY ( "hit_id" ) REFERENCES "hit"( "hit_id" ),
  FOREIGN KEY ( "protein_id" ) REFERENCES "protein"( "protein_id" )
) ;
CREATE INDEX ON "hit_protein" ( "hit_id" ) ;
CREATE INDEX ON "hit_protein" ( "protein_id" ) ;

DROP TABLE IF EXISTS "hit_domain" CASCADE ;
CREATE TABLE "hit_domain" (
  "hit_id" INTEGER  NOT NULL,
  "domain_id" INTEGER  NOT NULL,
  PRIMARY KEY ( "hit_id", "domain_id" ),
  FOREIGN KEY ( "hit_id" ) REFERENCES "hit"( "hit_id" ),
  FOREIGN KEY ( "domain_id" ) REFERENCES "domain"( "hit_id" )
) ;
CREATE INDEX ON "hit_domain" ( "hit_id" ) ;
CREATE INDEX ON "hit_domain" ( "domain_id" ) ;

DROP TABLE IF EXISTS "transcript_hit" CASCADE ;
CREATE TABLE "transcript_hit" (
  "probe_id" INTEGER  NOT NULL,
  "transcript_id" INTEGER  NOT NULL,
  "transcript_start" INTEGER  NOT NULL,
  "transcript_end" INTEGER  NOT NULL,
  FOREIGN KEY ( "transcript_id" ) REFERENCES "transcript"( "transcript_id" ),
  FOREIGN KEY ( "probe_id" ) REFERENCES "probe"( "probe_id" )
) ;
CREATE INDEX ON "transcript_hit" ( "probe_id" ) ;
CREATE INDEX ON "transcript_hit" ( "transcript_id" ) ;

DROP TABLE IF EXISTS "exon_transcript" CASCADE ;
CREATE TABLE "exon_transcript" (
  "exon_id" INTEGER  NOT NULL,
  "transcript_id" INTEGER  NOT NULL,
  "rank" INTEGER  NOT NULL,
  PRIMARY KEY ( "exon_id", "transcript_id", "rank" ),
  FOREIGN KEY ( "exon_id" ) REFERENCES "exon"( "exon_id" ),
  FOREIGN KEY ( "transcript_id" ) REFERENCES "transcript"( "transcript_id" )
) ;
CREATE INDEX ON "exon_transcript" ( "transcript_id" ) ;
CREATE INDEX ON "exon_transcript" ( "exon_id" ) ;

DROP TABLE IF EXISTS "est_gene" CASCADE ;
CREATE TABLE "est_gene" (
  "gene_id" INTEGER  NOT NULL,
  "stable_id" VARCHAR(128) NOT NULL,
  "chromosome_id" INTEGER  NOT NULL,
  "chromosome_name" VARCHAR(40) NOT NULL,
  "start" INTEGER  NOT NULL,
  "end" INTEGER  NOT NULL,
  "strand" SMALLINT,
  "biotype" VARCHAR(40),
  "status" VARCHAR(128),
  "description" TEXT,
  "synonym_id" INTEGER  DEFAULT NULL,
  "external_db_id" INTEGER  DEFAULT NULL,
  "db_display_name" VARCHAR(255) DEFAULT NULL,
  "symbol" VARCHAR(128) DEFAULT NULL,
  "symbol_description" TEXT DEFAULT NULL,
  PRIMARY KEY ( "gene_id" ),
  UNIQUE ( "stable_id" ),
  FOREIGN KEY ( "chromosome_id" ) REFERENCES "chromosome"( "chromosome_id" )
) ;
CREATE INDEX ON "est_gene" ( "chromosome_name" ) ;
CREATE INDEX ON "est_gene" ( "start" ) ;
CREATE INDEX ON "est_gene" ( "end" ) ;
CREATE INDEX ON "est_gene" ( "strand" ) ;
CREATE INDEX ON "est_gene" ( "synonym_id" ) ;

DROP TABLE IF EXISTS "hit_est_gene" CASCADE ;
CREATE TABLE "hit_est_gene" (
  "hit_id" INTEGER  NOT NULL,
  "gene_id" INTEGER  NOT NULL,
  PRIMARY KEY ( "hit_id", "gene_id" ),
  FOREIGN KEY ( "hit_id" ) REFERENCES "hit"( "hit_id" ),
  FOREIGN KEY ( "gene_id" ) REFERENCES "est_gene"( "gene_id" )
) ;
CREATE INDEX ON "hit_est_gene" ( "hit_id" ) ;
CREATE INDEX ON "hit_est_gene" ( "gene_id" ) ;

DROP TABLE IF EXISTS "est_exon" CASCADE ;
CREATE TABLE "est_exon" (
  "exon_id" INTEGER  NOT NULL,
  "stable_id" VARCHAR(128),
  "chromosome_id" INTEGER  NOT NULL,
  "chromosome_name" VARCHAR(40) NOT NULL,
  "start" INTEGER  NOT NULL,
  "end" INTEGER  NOT NULL,
  "strand" SMALLINT NOT NULL,
  "phase" SMALLINT NOT NULL,
  "end_phase" SMALLINT NOT NULL,
  "sequence" TEXT,
  PRIMARY KEY ( "exon_id" ),
  UNIQUE ( "stable_id" ),
  FOREIGN KEY ( "chromosome_id" ) REFERENCES "chromosome"( "chromosome_id" )
) ;
CREATE INDEX ON "est_exon" ( "chromosome_name" ) ;
CREATE INDEX ON "est_exon" ( "start" ) ;
CREATE INDEX ON "est_exon" ( "end" ) ;
CREATE INDEX ON "est_exon" ( "strand" ) ;

DROP TABLE IF EXISTS "hit_est_exon" CASCADE ;
CREATE TABLE "hit_est_exon" (
  "hit_id" INTEGER  NOT NULL,
  "exon_id" INTEGER  NOT NULL,
  PRIMARY KEY ( "hit_id", "exon_id" ),
  FOREIGN KEY ( "hit_id" ) REFERENCES "hit"( "hit_id" ),
  FOREIGN KEY ( "exon_id" ) REFERENCES "est_exon"( "exon_id" )
) ;
CREATE INDEX ON "hit_est_exon" ( "hit_id" ) ;
CREATE INDEX ON "hit_est_exon" ( "exon_id" ) ;

DROP TABLE IF EXISTS "est_transcript" CASCADE ;
CREATE TABLE "est_transcript" (
  "transcript_id" INTEGER  NOT NULL,
  "stable_id" VARCHAR(128) NOT NULL,
  "gene_id" INTEGER  NOT NULL,
  "chromosome_id" INTEGER  NOT NULL,
  "chromosome_name" VARCHAR(40) NOT NULL,
  "start" INTEGER  NOT NULL,
  "end" INTEGER  NOT NULL,
  "strand" SMALLINT NOT NULL,
  "biotype" VARCHAR(40) NOT NULL,
  "status" VARCHAR(128),
  "description" TEXT,
  "synonym_id" INTEGER  DEFAULT NULL,
  "external_db_id" INTEGER  DEFAULT NULL,
  "db_display_name" VARCHAR(255) DEFAULT NULL,
  "symbol" VARCHAR(128) DEFAULT NULL,
  "symbol_description" TEXT DEFAULT NULL,
  "translation_start" INTEGER,
  "translation_start_exon" INTEGER,
  "translation_end" INTEGER,
  "translation_end_exon" INTEGER,
  PRIMARY KEY ( "transcript_id" ),
  UNIQUE ( "stable_id" ),
  FOREIGN KEY ( "gene_id" ) REFERENCES "est_gene"( "gene_id" ),
  FOREIGN KEY ( "chromosome_id" ) REFERENCES "chromosome"( "chromosome_id" ),
  FOREIGN KEY ( "translation_start_exon" ) REFERENCES "est_exon"( "exon_id" ),
  FOREIGN KEY ( "translation_end_exon" ) REFERENCES "est_exon"( "exon_id" )
) ;
CREATE INDEX ON "est_transcript" ( "chromosome_name" ) ;
CREATE INDEX ON "est_transcript" ( "gene_id" ) ;
CREATE INDEX ON "est_transcript" ( "translation_start_exon" ) ;
CREATE INDEX ON "est_transcript" ( "translation_end_exon" ) ;
CREATE INDEX ON "est_transcript" ( "start" ) ;
CREATE INDEX ON "est_transcript" ( "end" ) ;
CREATE INDEX ON "est_transcript" ( "strand" ) ;
CREATE INDEX ON "est_transcript" ( "synonym_id" ) ;

DROP TABLE IF EXISTS "hit_est_transcript" CASCADE ;
CREATE TABLE "hit_est_transcript" (
  "hit_id" INTEGER  NOT NULL,
  "transcript_id" INTEGER  NOT NULL,
  PRIMARY KEY ( "hit_id", "transcript_id" ),
  FOREIGN KEY ( "hit_id" ) REFERENCES "hit"( "hit_id" ),
  FOREIGN KEY ( "transcript_id" ) REFERENCES "est_transcript"( "transcript_id" )
) ;
CREATE INDEX ON "hit_est_transcript" ( "hit_id" ) ;
CREATE INDEX ON "hit_est_transcript" ( "transcript_id" ) ;

DROP TABLE IF EXISTS "est_exon_transcript" CASCADE ;
CREATE TABLE "est_exon_transcript" (
  "exon_id" INTEGER  NOT NULL,
  "transcript_id" INTEGER  NOT NULL,
  "rank" INTEGER  NOT NULL,
  PRIMARY KEY ( "exon_id", "transcript_id", "rank" ),
  FOREIGN KEY ( "exon_id" ) REFERENCES "est_exon"( "exon_id" ),
  FOREIGN KEY ( "transcript_id" ) REFERENCES "est_transcript"( "transcript_id" )
) ;
CREATE INDEX ON "est_exon_transcript" ( "transcript_id" ) ;
CREATE INDEX ON "est_exon_transcript" ( "exon_id" ) ;

DROP TABLE IF EXISTS "prediction_transcript" CASCADE ;
CREATE TABLE "prediction_transcript" (
  "transcript_id" INTEGER  NOT NULL,
  "stable_id" VARCHAR(80) NOT NULL,
  "chromosome_id" INTEGER  NOT NULL,
  "chromosome_name" VARCHAR(40) NOT NULL,
  "start" INTEGER  NOT NULL,
  "end" INTEGER  NOT NULL,
  "strand" SMALLINT NOT NULL,
  PRIMARY KEY ( "transcript_id" ),
  UNIQUE ( "stable_id" ),
  FOREIGN KEY ( "chromosome_id" ) REFERENCES "chromosome"( "chromosome_id" )
) ;
CREATE INDEX ON "prediction_transcript" ( "chromosome_name" ) ;
CREATE INDEX ON "prediction_transcript" ( "start" ) ;
CREATE INDEX ON "prediction_transcript" ( "end" ) ;
CREATE INDEX ON "prediction_transcript" ( "strand" ) ;

DROP TABLE IF EXISTS "hit_prediction_transcript" CASCADE ;
CREATE TABLE "hit_prediction_transcript" (
  "hit_id" INTEGER  NOT NULL,
  "transcript_id" INTEGER  NOT NULL,
  PRIMARY KEY ( "hit_id", "transcript_id" ),
  FOREIGN KEY ( "hit_id" ) REFERENCES "hit"( "hit_id" ),
  FOREIGN KEY ( "transcript_id" ) REFERENCES "prediction_transcript"( "transcript_id" )
) ;
CREATE INDEX ON "hit_prediction_transcript" ( "hit_id" ) ;
CREATE INDEX ON "hit_prediction_transcript" ( "transcript_id" ) ;

DROP TABLE IF EXISTS "prediction_exon" CASCADE ;
CREATE TABLE "prediction_exon" (
  "exon_id" INTEGER  NOT NULL,
  "transcript_id" INTEGER  NOT NULL,
  "exon_rank" INTEGER  NOT NULL,
  "chromosome_id" INTEGER  NOT NULL,
  "chromosome_name" VARCHAR(40) NOT NULL,
  "start" INTEGER  NOT NULL,
  "end" INTEGER  NOT NULL,
  "strand" SMALLINT NOT NULL,
  "start_phase" SMALLINT,
  "sequence" TEXT,
  PRIMARY KEY ( "exon_id" ),
  FOREIGN KEY ( "chromosome_id" ) REFERENCES "chromosome"( "chromosome_id" ),
  FOREIGN KEY ( "transcript_id" ) REFERENCES "prediction_transcript"( "transcript_id" )
) ;
CREATE INDEX ON "prediction_exon" ( "transcript_id" ) ;
CREATE INDEX ON "prediction_exon" ( "chromosome_name" ) ;
CREATE INDEX ON "prediction_exon" ( "start" ) ;
CREATE INDEX ON "prediction_exon" ( "end" ) ;
CREATE INDEX ON "prediction_exon" ( "strand" ) ;

DROP TABLE IF EXISTS "hit_prediction_exon" CASCADE ;
CREATE TABLE "hit_prediction_exon" (
  "hit_id" INTEGER  NOT NULL,
  "exon_id" INTEGER  NOT NULL,
  PRIMARY KEY ( "hit_id", "exon_id" ),
  FOREIGN KEY ( "hit_id" ) REFERENCES "hit"( "hit_id" ),
  FOREIGN KEY ( "exon_id" ) REFERENCES "prediction_exon"( "exon_id" )
) ;
CREATE INDEX ON "hit_prediction_exon" ( "hit_id" ) ;
CREATE INDEX ON "hit_prediction_exon" ( "exon_id" ) ;

DROP TABLE IF EXISTS "variation" CASCADE ;
CREATE TABLE "variation" (
  "variation_feature_id" INTEGER     NOT NULL,
  "stable_id" VARCHAR(255)   DEFAULT NULL,
  "chromosome_id" INTEGER     NOT NULL,
  "start" INTEGER     NOT NULL,
  "end" INTEGER     NOT NULL,
  "strand" SMALLINT     NOT NULL,
  "allele_string" VARCHAR(50000) DEFAULT NULL,
  "allele_freq" FLOAT          DEFAULT NULL,
  "minor_allele" CHAR(1)        DEFAULT NULL,
  "attrib_class" TEXT,
  "source" VARCHAR(255)   DEFAULT NULL,
  "validation_status" VARCHAR(80) DEFAULT NULL,
  PRIMARY KEY ( "variation_feature_id" ),
  FOREIGN KEY ( "chromosome_id" ) REFERENCES "chromosome"( "chromosome_id" )
) ;
CREATE INDEX ON "variation" ( "start", "end", "strand" ) ;
CREATE INDEX ON "variation" ( "stable_id" ) ;

DROP TABLE IF EXISTS "transcript_variation" CASCADE ;
CREATE TABLE "transcript_variation" (
  "variation_feature_id" INTEGER   NOT NULL,
  "consequence_types" VARCHAR(80) DEFAULT NULL,
  "pep_allele_string" TEXT,
  "translation_start" INTEGER   DEFAULT NULL,
  "translation_end" INTEGER   DEFAULT NULL,
  "sift_score" FLOAT        DEFAULT NULL,
  "polyphen_score" FLOAT        DEFAULT NULL,
  "feature_stable_id" VARCHAR(128) DEFAULT NULL,
  FOREIGN KEY ( "variation_feature_id" ) REFERENCES "variation"( "variation_feature_id" )
) ;
CREATE INDEX ON "transcript_variation" ( "variation_feature_id" ) ;
CREATE INDEX ON "transcript_variation" ( "feature_stable_id" ) ;

